%define module_name dkms-open-iscsi

%define with_dkms 0

%define libiscsi_major     0
%define libiscsi_libname   %mklibname openiscsiusr %{libiscsi_major}
# We have two libiscsi libs with different APIs and versions, so keep
# the somajor in the devel package name
%define libiscsi_develname %mklibname iscsi %{libiscsi_major} -d

Name:           open-iscsi
Version:        2.1.10
Release:        %mkrel 2
Summary:        An implementation of RFC3720 iSCSI
License:        GPL-2.0
Group:          Networking/Other
URL:            https://github.com/open-iscsi/open-iscsi
Source0:        https://github.com/open-iscsi/open-iscsi/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        open-iscsi.service

#
# Mageia patches
#

BuildRequires:  meson
BuildRequires:  bison
BuildRequires:  db-devel
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  glibc-static-devel
BuildRequires:  pkgconfig(libisns)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(mount)

Provides:       iscsi-initiator-utils

%description
Open-iSCSI project is a high-performance, transport independent, multi-platform
implementation of RFC3720 iSCSI. iSCSI is a protocol for distributed disk
access using SCSI commands sent over Internet Protocol networks.

%if %{with_dkms}
%package -n %{module_name}
Summary:        open-iscsi initiator kernel module
Group:          Networking/Other
Requires:       kernel-source
Requires(preun): dkms
Requires(post):  dkms

%description -n %{module_name}
This package contains the open-iscsi initiator kernel module.
%endif

%package -n %{libiscsi_libname}
Summary:        Libraries for libiscsi
Group:          System/Libraries

%description -n %{libiscsi_libname}
This package contains the shared libiscsi library.

%package -n %{libiscsi_develname}
Summary:        Development libraries, header files for libiscsi
Group:          Development/C
Requires:       %{libiscsi_libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       iscsi-initiator-utils-devel = %{version}-%{release}
Provides:       iscsi-devel = %{version}-%{release}

%description -n %{libiscsi_develname}
This package contains libraries and header files for developing applications
that use libiscsi.

%prep
%autosetup -p1

%build
%meson -Drulesdir=%{_udevrulesdir}
%meson_build

%install
%meson_install

mkdir -p -m 0700 %{buildroot}%{_localstatedir}/lib/open-iscsi
mkdir -p -m 0755 %{buildroot}%{_sysconfdir}/iscsi/nodes
mkdir -p -m 0755 %{buildroot}%{_sysconfdir}/iscsi/send_targets

install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/open-iscsi.service


# DKMS
%if %{with_dkms}
mkdir -p %{buildroot}/usr/src/%{module_name}-%{version}
cp -a kernel %{buildroot}/usr/src/%{module_name}-%{version}/
cp -a include %{buildroot}/usr/src/%{module_name}-%{version}/

cat > %{buildroot}/usr/src/%{module_name}-%{version}/dkms.conf <<EOF
PACKAGE_VERSION="%{version}"
PACKAGE_NAME="%{module_name}"
MAKE[0]="cd \${dkms_tree}/\${PACKAGE_NAME}/\${PACKAGE_VERSION}/build/kernel ; make"
CLEAN="cd \${dkms_tree}/\${PACKAGE_NAME}/\${PACKAGE_VERSION}/build/kernel ; make clean"

BUILT_MODULE_NAME[0]="iscsi_tcp"
BUILT_MODULE_LOCATION[0]="kernel"
DEST_MODULE_NAME[0]="iscsi_tcp"
DEST_MODULE_LOCATION[0]="/kernel/drivers/scsi"

BUILT_MODULE_NAME[1]="scsi_transport_iscsi"
BUILT_MODULE_LOCATION[1]="kernel"
DEST_MODULE_NAME[1]="scsi_transport_iscsi"
DEST_MODULE_LOCATION[1]="/kernel/drivers/scsi"

REMAKE_INITRD="no"
AUTOINSTALL=yes
POST_INSTALL="post-install"
POST_REMOVE="post-remove"
EOF
%endif

%post
echo "InitiatorName=`/usr/sbin/iscsi-iname`" > %{_sysconfdir}/iscsi/initiatorname.iscsi
%_post_service open-iscsi

%if %{with_dkms}
%post -n %{module_name}
dkms add -m %{module_name} -v %{version} --rpm_safe_upgrade
dkms build -m %{module_name} -v %{version} --rpm_safe_upgrade
dkms install -m %{module_name} -v %{version} --rpm_safe_upgrade
%endif

%preun
%_preun_service open-iscsi

%if %{with_dkms}
%preun -n %{module_name}
dkms remove -m %{module_name} -v %{version} --rpm_safe_upgrade --all || :
%endif

%files
%doc README
%license COPYING
%dir %{_sysconfdir}/iscsi
%dir %{_sysconfdir}/iscsi/nodes
%dir %{_sysconfdir}/iscsi/send_targets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/iscsi/iscsid.conf
%config(noreplace) %{_sysconfdir}/iscsi/initiatorname.iscsi
%{_sysconfdir}/logrotate.d/iscsiuiolog
%{_udevrulesdir}/50-iscsi-firmware-login.rules
%{_unitdir}/open-iscsi.service
%{_unitdir}/iscsi-init.service
%{_unitdir}/iscsi.service
%{_unitdir}/iscsid.service
%{_unitdir}/iscsid.socket
%{_unitdir}/iscsiuio.service
%{_unitdir}/iscsiuio.socket
%{_systemdgeneratordir}/ibft-rule-generator
%_sbindir/iscsiadm
%_sbindir/iscsid
%_sbindir/iscsi-iname
%_sbindir/iscsistart
%_sbindir/iscsiuio
%_sbindir/brcm_iscsiuio
%_sbindir/iscsi-gen-initiatorname
%_sbindir/iscsi_discovery
%_sbindir/iscsi_fw_login
%_sbindir/iscsi_offload
%{_mandir}/man8/iscsiadm.8*
%{_mandir}/man8/iscsid.8*
%{_mandir}/man8/iscsi_discovery.8*
%{_mandir}/man8/iscsi-iname.8*
%{_mandir}/man8/iscsi_fw_login.8*
%{_mandir}/man8/iscsistart.8*
%{_mandir}/man8/iscsiuio.8*
%{_mandir}/man8/iscsi-gen-initiatorname.8*
%{_localstatedir}/lib/iscsi/ifaces/iface.example
%dir %{_localstatedir}/lib/iscsi
%dir %{_localstatedir}/lib/iscsi/ifaces
%dir %{_localstatedir}/lib/open-iscsi

%if %{with_dkms}
%files -n %{module_name}
%_usrsrc/%{module_name}-%{version}
%endif

%files -n %{libiscsi_libname}
%license COPYING
%{_libdir}/libopeniscsiusr.so.%{libiscsi_major}{,.*}

%files -n %{libiscsi_develname}
%_includedir/libopeniscsiusr.h
%_includedir/libopeniscsiusr_common.h
%_includedir/libopeniscsiusr_iface.h
%_includedir/libopeniscsiusr_node.h
%_includedir/libopeniscsiusr_session.h
%_libdir/pkgconfig/libopeniscsiusr.pc
%{_libdir}/libopeniscsiusr.so
%{_mandir}/man3/*.3*


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 2.1.10-2.mga10
+ Revision: 2230984
- Mageia 10 Mass Rebuild

* Fri Dec 06 2024 daviddavid <daviddavid> 2.1.10-1.mga10
+ Revision: 2121897
- new version: 2.1.10
- switch to meson build system

* Wed Mar 30 2022 umeabot <umeabot> 2.1.3-872.23.mga9
+ Revision: 1833645
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.1.3-872.22.mga9
+ Revision: 1748399
- rebuild for openssl 3.0.0

* Tue Mar 23 2021 neoclust <neoclust> 2.1.3-872.21.mga9
+ Revision: 1708395
- Fix 2 crashes ( upstream commits)

* Tue Jan 26 2021 neoclust <neoclust> 2.1.3-872.20.mga8
+ Revision: 1673416
- New version 2.1.3
- New version 2.1.3

* Tue Dec 15 2020 wally <wally> 2.0-872.20.mga8
+ Revision: 1657860
- honor CFLAGS when building iscsiuio
+ joequant <joequant>
- fix build

* Sat Feb 15 2020 daviddavid <daviddavid> 2.0-872.19.mga8
+ Revision: 1526124
- drop python2 support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Apr 10 2019 ngompa <ngompa> 2.0-872.18.mga7
+ Revision: 1387893
- Add additional compatibility Provides to devel subpackage

* Wed Apr 10 2019 ngompa <ngompa> 2.0-872.17.mga7
+ Revision: 1387891
- Add somajor to devel subpackage name to unmask the other libiscsi package

* Sat Sep 29 2018 daviddavid <daviddavid> 2.0-872.16.mga7
+ Revision: 1310903
- add gentoo to fix build with new glibc
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Jun 24 2018 wally <wally> 2.0-872.15.mga7
+ Revision: 1239490
- fix build on aarch64
- add upstream patch to fix duplicate definition of __bitwise

* Mon Jan 22 2018 tv <tv> 2.0-872.14.mga7
+ Revision: 1195793
- fix build

* Wed Oct 19 2016 tv <tv> 2.0-872.13.mga6
+ Revision: 1062392
- switch from %%old_configure to %%configure2_5x (why was it used in the 1st place???)

* Sun May 01 2016 tv <tv> 2.0-872.12.mga6
+ Revision: 1008488
- revert provides libiscsi-devel

* Fri Apr 15 2016 tv <tv> 2.0-872.11.mga6
+ Revision: 1001837
- provides libiscsi-devel

* Tue Jan 05 2016 pterjan <pterjan> 2.0-872.10.mga6
+ Revision: 919803
- Fix build

* Wed Oct 15 2014 umeabot <umeabot> 2.0-872.9.mga5
+ Revision: 745611
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.0-872.8.mga5
+ Revision: 727523
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0-872.7.mga5
+ Revision: 683181
- Mageia 5 Mass Rebuild

* Tue Feb 25 2014 zezinho <zezinho> 2.0-872.6.mga5
+ Revision: 597154
- create usable configfile at install #12877

* Sat Jan 25 2014 neoclust <neoclust> 2.0-872.5.mga4
+ Revision: 568136
- Obsolete same rpm with other name
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Tue Jul 02 2013 oden <oden> 2.0-872.3.mga4
+ Revision: 449657
- fix #10527 (open-iscsi does not start, due to kernel module not loaded)

* Sun Jan 13 2013 umeabot <umeabot> 2.0-872.2.mga3
+ Revision: 361879
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Sep 14 2012 oden <oden> 2.0-872.1.mga3
+ Revision: 293804
- sync with redhat (iscsi-initiator-utils-6.2.0.872-19.fc18.src.rpm)
- added the libiscsi library and python sub packages
- rediffed some patches and drop redundant ones

* Tue Aug 14 2012 luigiwalser <luigiwalser> 2.0-871.6.mga3
+ Revision: 281345
- add patch from ubuntu to fix CVE-2009-1297

* Tue Aug 14 2012 guillomovitch <guillomovitch> 2.0-871.5.mga3
+ Revision: 281306
- add systemd support
- drop sysinit support

* Thu Jan 13 2011 tmb <tmb> 2.0-871.4.mga1
+ Revision: 8932
- imported package open-iscsi


* Thu Jan 13 2011 Thomas Backlund <tmb@mageia.org> 2.0-871.4.mga1
- initial Mageia import

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0-871.3mdv2011.0
+ Revision: 607175
- fix build
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0-871.2mdv2010.1
+ Revision: 523494
- rebuilt for 2010.1

* Sun Aug 30 2009 Andrey Borzenkov <arvidjaar@mandriva.org> 2.0-871.1mdv2010.0
+ Revision: 422368
- new version 871 with current kernel support, including
  * patch1 - install contents of /etc/iscsi unconditionally
  * install ifaces.example as well
  * call top-level target `user' instead of explicitly listing sub-targets

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 2.0-869.2.2mdv2009.0
+ Revision: 268349
- rebuild early 2009.0 package (before pixel changes)

* Sun Jun 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.0-869.2.1mdv2009.0
+ Revision: 216909
- new version

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.0-865.15.1mdv2008.1
+ Revision: 121685
- new version

* Wed Aug 08 2007 Olivier Thauvin <nanardon@mandriva.org> 2.0-865.9.1mdv2008.0
+ Revision: 60115
- 2.0-865.9

* Thu Jun 28 2007 Andreas Hasenack <andreas@mandriva.com> 2.0-865.3.1mdv2008.0
+ Revision: 45542
- updated to version 2.0-865.3
- using serverbuild macro (-fstack-protector-all)

* Mon May 14 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.0-754.2mdv2008.0
+ Revision: 26738
- Updated initscript for new version.

* Fri Apr 27 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.0-1.754mdv2008.0
+ Revision: 18675
- Updated to 2.0-754.
- Added missing BuildRequires for glibc-static-devel.
- Own nodes and send_targets directories.


* Wed Nov 22 2006 Andreas Hasenack <andreas@mandriva.com> 1.0-1.485.2mdv2007.0
+ Revision: 86334
- several initscript improvements, taken from CS4 package
- awk patch to fix kernel versioning detection during build
- provide a default initiatorname.iscsi file to ease configuration
- add support for dkms build, also taken from CS4 (disabled by default)
- cleanup on stop, touch on start
- workaround to kill the two daemons
- use HUP instead of KILL to stop the daemon
- fixed db path
- added sed to buildrequires
- added initial workings of an init script
- register service
- Import open-iscsi

